@@ -98,7 +98,9 @@ cube_upload_param["mtdi_id"]=None
 cube_it.up_load_to_cube(conn=conn,cube_upload_param=cube_upload_param)
 """
 #
-obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4','C6B60AF341D38FF8DC6F3AA8D11D3115;55'] #Dossier & metric "hire date"
+
+obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4','C6B60AF341D38FF8DC6F3AA8D11D3115;55']
+#obj_id_l=['335FFA9640B5F1C1E0C0F3A469E627A8;55','59D59D7741F61B68480572B9B7A05709;4','C6B60AF341D38FF8DC6F3AA8D11D3115;55'] #Dossier & metric "hire date"
 used_obj_dict_l=mig_search.used_by_obj_l_rec(conn=conn,project_id=change_log_report["chg_log_rep_proj_id"]
                           ,obj_id_l=obj_id_l)
 #export search result to cube
